use neo_entity::devices::{self, Entity as Device};
use sea_orm_migration::prelude::*;

pub struct Migration;

impl MigrationName for Migration {
    fn name(&self) -> &str {
        "m20220707_112339_create_devices.rs"
    }
}

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Device)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(devices::Column::Uuid)
                            .uuid()
                            .primary_key()
                            .not_null(),
                    )
                    .col(ColumnDef::new(devices::Column::UserUuid).uuid().not_null())
                    .col(
                        ColumnDef::new(devices::Column::DeviceId)
                            .string()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(devices::Column::DisplayName)
                            .string()
                            .not_null(),
                    )
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .table(Device)
                    .col(devices::Column::DeviceId)
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .table(Device)
                    .col(devices::Column::UserUuid)
                    .to_owned(),
            )
            .await
    }
}
