use neo_entity::sessions::{self, Entity as Session};
use sea_orm_migration::prelude::*;

pub struct Migration;

impl MigrationName for Migration {
    fn name(&self) -> &str {
        "m20220707_143304_create_sessions.rs"
    }
}

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Session)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(sessions::Column::Uuid)
                            .uuid()
                            .primary_key()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(sessions::Column::DeviceUuid)
                            .uuid()
                            .not_null(),
                    )
                    .col(ColumnDef::new(sessions::Column::Key).string().not_null())
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .table(Session)
                    .col(sessions::Column::DeviceUuid)
                    .to_owned(),
            )
            .await
    }
}
