use std::sync::Arc;

use axum::routing::post;
use axum::Extension;

use crate::api::client_server::errors::api_error::ApiError;
use neo_entity::prelude::*;
use crate::ruma_wrapper::{RumaRequest, RumaResponse};

use ruma::api::client::filter;

pub fn routes() -> axum::Router {
    axum::Router::new()
        .route("/r0/user/:user_id/filter", post(create_filter))
        .layer(axum::middleware::from_fn(super::authentication_middleware))
}

async fn create_filter(
    Extension(_user): Extension<Arc<User>>,
    RumaRequest(_req): RumaRequest<filter::create_filter::v3::IncomingRequest>,
) -> Result<RumaResponse<filter::create_filter::v3::Response>, ApiError> {
    use filter::create_filter::v3::*;

    Ok(RumaResponse(Response::new("a".into())))
}
