use std::sync::Arc;

use axum::routing::{get, put};
use axum::Extension;

use crate::api::client_server::errors::api_error::ApiError;
use neo_entity::prelude::*;
use crate::ruma_wrapper::{RumaRequest, RumaResponse};

use ruma::api::client::presence;
use ruma::presence::PresenceState;

pub fn routes() -> axum::Router {
    axum::Router::new()
        .route("/r0/presence/:user_id/status", put(set_presence))
        .route("/r0/presence/:user_id/status", get(get_presence))
        .layer(axum::middleware::from_fn(super::authentication_middleware))
}

async fn set_presence(
    Extension(_user): Extension<Arc<User>>,
    RumaRequest(_req): RumaRequest<presence::set_presence::v3::IncomingRequest>,
) -> Result<RumaResponse<presence::set_presence::v3::Response>, ApiError> {
    use presence::set_presence::v3::*;

    Ok(RumaResponse(Response::new()))
}

async fn get_presence(
    Extension(_user): Extension<Arc<User>>,
    RumaRequest(_req): RumaRequest<presence::get_presence::v3::IncomingRequest>,
) -> Result<RumaResponse<presence::get_presence::v3::Response>, ApiError> {
    use presence::get_presence::v3::*;

    Ok(RumaResponse(Response::new(PresenceState::Unavailable)))
}
