use std::sync::Arc;

use axum::routing::get;
use axum::Extension;

use crate::api::client_server::errors::api_error::ApiError;
use neo_entity::prelude::*;
use crate::ruma_wrapper::{RumaRequest, RumaResponse};

use ruma::api::client::push;
use ruma::push::Ruleset;

pub fn routes() -> axum::Router {
    axum::Router::new()
        .route("/r0/pushrules/", get(get_pushrules))
        .layer(axum::middleware::from_fn(super::authentication_middleware))
}

async fn get_pushrules(
    Extension(_user): Extension<Arc<User>>,
    RumaRequest(_req): RumaRequest<push::get_pushrules_all::v3::IncomingRequest>
) -> Result<RumaResponse<push::get_pushrules_all::v3::Response>, ApiError> {
    use push::get_pushrules_all::v3::*;

    Ok(RumaResponse(Response::new(Ruleset::new())))
}
