use std::sync::Arc;

use axum::routing::get;
use axum::Extension;

use crate::api::client_server::errors::api_error::ApiError;
use crate::ruma_wrapper::{RumaRequest, RumaResponse};
use neo_entity::prelude::*;

use ruma::api::client::sync;

pub fn routes() -> axum::Router {
    axum::Router::new()
        .route("/r0/sync", get(sync_events))
        .layer(axum::middleware::from_fn(super::authentication_middleware))
}

async fn sync_events(
    Extension(_user): Extension<Arc<User>>,
    RumaRequest(req): RumaRequest<sync::sync_events::v3::IncomingRequest>,
) -> Result<RumaResponse<sync::sync_events::v3::Response>, ApiError> {
    use sync::sync_events::v3::*;

    if let Some(timeout) = req.timeout {
        tokio::time::sleep(timeout).await;
    }

    Ok(RumaResponse(Response::new("todo".into())))
}
