use sqlx::{encode::IsNull, Sqlite};

#[derive(Debug, Clone, PartialEq, Eq, Hash)]
pub enum EventType {
    RoomCreate,
    Unknown,
}

impl sqlx::Type<Sqlite> for EventType {
    fn type_info() -> <Sqlite as sqlx::Database>::TypeInfo {
        <&str as sqlx::Type<Sqlite>>::type_info()
    }
}

impl<'e> sqlx::Encode<'e, Sqlite> for EventType {
    fn encode_by_ref(
        &self,
        buf: &mut <Sqlite as sqlx::database::HasArguments<'e>>::ArgumentBuffer,
    ) -> sqlx::encode::IsNull {
        buf.push(sqlx::sqlite::SqliteArgumentValue::Text(
            match self {
                EventType::RoomCreate => "m.room.create",
                EventType::Unknown => "???",
            }
            .into(),
        ));

        IsNull::No
    }
}

impl<'d> sqlx::Decode<'d, Sqlite> for EventType {
    fn decode(
        value: <Sqlite as sqlx::database::HasValueRef<'d>>::ValueRef,
    ) -> Result<Self, sqlx::error::BoxDynError> {
        Ok(match <&str as sqlx::Decode<Sqlite>>::decode(value)? {
            "m.room.create" => EventType::RoomCreate,
            _ => EventType::Unknown,
        })
    }
}

impl serde::Serialize for EventType {
    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
    where
        S: serde::Serializer,
    {
        serializer.serialize_str(match self {
            EventType::RoomCreate => "m.room.create",
            EventType::Unknown => "dev.fuckwit.unknown_event",
        })
    }
}

impl<'de> serde::Deserialize<'de> for EventType {
    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
    where
        D: serde::Deserializer<'de>,
    {
        struct IdentifierVisitor;

        impl<'de> serde::de::Visitor<'de> for IdentifierVisitor {
            type Value = EventType;

            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
                formatter.write_str("Identifier")
            }

            fn visit_borrowed_str<E>(self, v: &'de str) -> Result<Self::Value, E>
            where
                E: serde::de::Error,
            {
                match v {
                    "m.id.user" => Ok(EventType::RoomCreate),
                    _ => Err(serde::de::Error::custom("Unknown identifier")),
                }
            }
        }

        deserializer.deserialize_str(IdentifierVisitor {})
    }
}
